==> hoauth_0.2.3.orig.tar.gz: hoauth-0.2.3/src/main/haskell/Network/OAuth/Http/Response.hs <==
-- Copyright (c) 2009, Diego Souza
-- All rights reserved.
-- 
-- Redistribution and use in source and binary forms, with or without
-- modification, are permitted provided that the following conditions are met:
-- 
--   * Redistributions of source code must retain the above copyright notice,
--     this list of conditions and the following disclaimer.
--   * Redistributions in binary form must reproduce the above copyright notice,
--     this list of conditions and the following disclaimer in the documentation
--     and/or other materials provided with the distribution.
--   * Neither the name of the <ORGANIZATION> nor the names of its contributors
--     may be used to endorse or promote products derived from this software
--     without specific prior written permission.
-- 
-- THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
-- ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-- WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
-- DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
-- FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
-- DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
-- SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
-- CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
-- OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-- OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

-- | The response of the server for a given "Request". Similarly to "Request",
-- it is currently only able to represent HTTP responses.
module Network.OAuth.Http.Response (Response(..)
                                   ) where

import Data.ByteString.Lazy as B
import Network.OAuth.Http.Request (FieldList)

data Response = RspHttp {status     :: Int           -- ^ The status code (e.g. 200, 302)
                        ,statusLine :: String        -- ^ The message that comes along with the status (e.g. HTTP/1.1 200 OK)
                        ,rspHeaders :: FieldList     -- ^ The response headers
                        ,rspPayload :: B.ByteString  -- ^ The body of the message
                        }
  deriving (Show)

-- contentType :: Response -> (String,FieldList)
-- contentType = let string         = findWithDefault ("content-type","text/html") . rspHeaders
--                   (type_,params) = break (==';') string
--               in (trim type_,trim charset)

-- vim:sts=2:sw=2:ts=2:et

==> hoauth_0.3.4.orig.tar.gz: hoauth-0.3.4/src/main/haskell/Network/OAuth/Http/Response.hs <==
-- Copyright (c) 2009, Diego Souza
-- All rights reserved.
-- 
-- Redistribution and use in source and binary forms, with or without
-- modification, are permitted provided that the following conditions are met:
-- 
--   * Redistributions of source code must retain the above copyright notice,
--     this list of conditions and the following disclaimer.
--   * Redistributions in binary form must reproduce the above copyright notice,
--     this list of conditions and the following disclaimer in the documentation
--     and/or other materials provided with the distribution.
--   * Neither the name of the <ORGANIZATION> nor the names of its contributors
--     may be used to endorse or promote products derived from this software
--     without specific prior written permission.
-- 
-- THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
-- ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-- WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
-- DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
-- FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
-- DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
-- SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
-- CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
-- OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-- OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

-- | The response of the server for a given "Request". Similarly to "Request",
-- it is currently only able to represent HTTP responses.
module Network.OAuth.Http.Response 
       ( Response(..)
       ) where

import Data.ByteString.Lazy as B
import Network.OAuth.Http.Request (FieldList)

data Response = RspHttp { status     :: Int           -- ^ The status code (e.g. 200, 302)
                        , reason     :: String        -- ^ The message that comes along with the status (e.g. HTTP/1.1 200 OK)
                        , rspHeaders :: FieldList     -- ^ The response headers
                        , rspPayload :: B.ByteString  -- ^ The body of the message
                        }
              deriving (Show)

-- contentType :: Response -> (String,FieldList)
-- contentType = let string         = findWithDefault ("content-type","text/html") . rspHeaders
--                   (type_,params) = break (==';') string
--               in (trim type_,trim charset)
